# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .cart import (
    CartResource,
    AsyncCartResource,
    CartResourceWithRawResponse,
    AsyncCartResourceWithRawResponse,
    CartResourceWithStreamingResponse,
    AsyncCartResourceWithStreamingResponse,
)
from .orders import (
    OrdersResource,
    AsyncOrdersResource,
    OrdersResourceWithRawResponse,
    AsyncOrdersResourceWithRawResponse,
    OrdersResourceWithStreamingResponse,
    AsyncOrdersResourceWithStreamingResponse,
)
from .wallet import (
    WalletResource,
    AsyncWalletResource,
    WalletResourceWithRawResponse,
    AsyncWalletResourceWithRawResponse,
    WalletResourceWithStreamingResponse,
    AsyncWalletResourceWithStreamingResponse,
)
from .checkout import (
    CheckoutResource,
    AsyncCheckoutResource,
    CheckoutResourceWithRawResponse,
    AsyncCheckoutResourceWithRawResponse,
    CheckoutResourceWithStreamingResponse,
    AsyncCheckoutResourceWithStreamingResponse,
)
from .products import (
    ProductsResource,
    AsyncProductsResource,
    ProductsResourceWithRawResponse,
    AsyncProductsResourceWithRawResponse,
    ProductsResourceWithStreamingResponse,
    AsyncProductsResourceWithStreamingResponse,
)
from .merchants import (
    MerchantsResource,
    AsyncMerchantsResource,
    MerchantsResourceWithRawResponse,
    AsyncMerchantsResourceWithRawResponse,
    MerchantsResourceWithStreamingResponse,
    AsyncMerchantsResourceWithStreamingResponse,
)

__all__ = [
    "ProductsResource",
    "AsyncProductsResource",
    "ProductsResourceWithRawResponse",
    "AsyncProductsResourceWithRawResponse",
    "ProductsResourceWithStreamingResponse",
    "AsyncProductsResourceWithStreamingResponse",
    "CartResource",
    "AsyncCartResource",
    "CartResourceWithRawResponse",
    "AsyncCartResourceWithRawResponse",
    "CartResourceWithStreamingResponse",
    "AsyncCartResourceWithStreamingResponse",
    "CheckoutResource",
    "AsyncCheckoutResource",
    "CheckoutResourceWithRawResponse",
    "AsyncCheckoutResourceWithRawResponse",
    "CheckoutResourceWithStreamingResponse",
    "AsyncCheckoutResourceWithStreamingResponse",
    "OrdersResource",
    "AsyncOrdersResource",
    "OrdersResourceWithRawResponse",
    "AsyncOrdersResourceWithRawResponse",
    "OrdersResourceWithStreamingResponse",
    "AsyncOrdersResourceWithStreamingResponse",
    "WalletResource",
    "AsyncWalletResource",
    "WalletResourceWithRawResponse",
    "AsyncWalletResourceWithRawResponse",
    "WalletResourceWithStreamingResponse",
    "AsyncWalletResourceWithStreamingResponse",
    "MerchantsResource",
    "AsyncMerchantsResource",
    "MerchantsResourceWithRawResponse",
    "AsyncMerchantsResourceWithRawResponse",
    "MerchantsResourceWithStreamingResponse",
    "AsyncMerchantsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ProductSearchResponse", "Data"]


class Data(BaseModel):
    id: str

    currency: str

    description: str

    image_url: str = FieldInfo(alias="imageUrl")

    name: str

    price: float

    source: str

    original_price: Optional[str] = FieldInfo(alias="originalPrice", default=None)


class ProductSearchResponse(BaseModel):
    data: List[Data]

    message: str

    status: str

    success: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["MerchantListSupportedResponse", "Data", "DataMerchant", "DataPagination"]


class DataMerchant(BaseModel):
    id: str

    domain: str

    name: str

    website: Optional[str] = None


class DataPagination(BaseModel):
    current_page: float = FieldInfo(alias="currentPage")

    has_next_page: bool = FieldInfo(alias="hasNextPage")

    has_previous_page: bool = FieldInfo(alias="hasPreviousPage")

    limit: float

    total_count: float = FieldInfo(alias="totalCount")

    total_pages: float = FieldInfo(alias="totalPages")


class Data(BaseModel):
    merchants: List[DataMerchant]

    pagination: DataPagination


class MerchantListSupportedResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .session import (
    SessionResource,
    AsyncSessionResource,
    SessionResourceWithRawResponse,
    AsyncSessionResourceWithRawResponse,
    SessionResourceWithStreamingResponse,
    AsyncSessionResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["CheckoutResource", "AsyncCheckoutResource"]


class CheckoutResource(SyncAPIResource):
    @cached_property
    def session(self) -> SessionResource:
        return SessionResource(self._client)

    @cached_property
    def with_raw_response(self) -> CheckoutResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return CheckoutResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CheckoutResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return CheckoutResourceWithStreamingResponse(self)


class AsyncCheckoutResource(AsyncAPIResource):
    @cached_property
    def session(self) -> AsyncSessionResource:
        return AsyncSessionResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncCheckoutResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return AsyncCheckoutResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCheckoutResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return AsyncCheckoutResourceWithStreamingResponse(self)


class CheckoutResourceWithRawResponse:
    def __init__(self, checkout: CheckoutResource) -> None:
        self._checkout = checkout

    @cached_property
    def session(self) -> SessionResourceWithRawResponse:
        return SessionResourceWithRawResponse(self._checkout.session)


class AsyncCheckoutResourceWithRawResponse:
    def __init__(self, checkout: AsyncCheckoutResource) -> None:
        self._checkout = checkout

    @cached_property
    def session(self) -> AsyncSessionResourceWithRawResponse:
        return AsyncSessionResourceWithRawResponse(self._checkout.session)


class CheckoutResourceWithStreamingResponse:
    def __init__(self, checkout: CheckoutResource) -> None:
        self._checkout = checkout

    @cached_property
    def session(self) -> SessionResourceWithStreamingResponse:
        return SessionResourceWithStreamingResponse(self._checkout.session)


class AsyncCheckoutResourceWithStreamingResponse:
    def __init__(self, checkout: AsyncCheckoutResource) -> None:
        self._checkout = checkout

    @cached_property
    def session(self) -> AsyncSessionResourceWithStreamingResponse:
        return AsyncSessionResourceWithStreamingResponse(self._checkout.session)
